@@ -16,7 +16,7 @@
 # in the module but are exported as public interface.
 
 from .adminlite import AdminClient,AdminServer
-from .tools import Tools,Logit
+from .tools import Tools,Logit,Retryit
 from .commengine import CommEngineTCP,CommEngine,Session
 from .safeengine import SafeEngine,X25519
 from .msgengine import MsgEngine
