@@ -83,7 +83,7 @@ class SafeEngine(object):
             str: md5 with base64 encode
         '''
         salt = os.urandom(8)
-        return base64.b64encode(salt+md5(salt+msg.encode()).digest())
+        return base64.b64encode(salt+md5(salt+msg.encode()).digest()).decode()
     @staticmethod
     def verify_salt_md5(msg:str,msg_md5:str)->bool:
         '''
