@@ -339,7 +339,34 @@ class Tools(object):
         webbrowser.open(markdown_filename+".html")
         pass
 
+class Retryit(object):
+    '''
+    function should be return True if success!
 
+    Args:
+        object (_type_): _description_
+    '''
+    def __init__(self, retry_count:int=3,timeout:int= 5):
+        self.retry_count = retry_count
+        self.timeout = timeout
+
+    def __call__(self, func):
+        @wraps(func)
+        def wrapped_function(*args, **kwargs):
+            _count = 0
+            while _count < self.retry_count:
+                logging.debug("try {} time.".format(_count))
+                result = func(*args, **kwargs)
+                _count += 1
+                if result:
+                    break
+            if _count==self.retry_count:
+                logging.info("Failure after {} retry!".format(self.retry_count))
+            return result
+        return wrapped_function
+ 
+    def notify(self):
+        pass
  
 class Logit(object):
     def __init__(self, level="debug"):
